<?php

namespace Drupal\codes_pool\Plugin\codes_pool\CollectionSource;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * Defines the base interface for collection.
 */
interface CollectionSourceInterface extends ConfigurableInterface, PluginFormInterface, PluginInspectionInterface {

  /**
   * Gets the collection entity type ID.
   *
   * @return string
   *   The collection's entity type ID.
   */
  public function getEntityTypeId(): string;

  /**
   * Checks if the codes can be stored locally.
   *
   * @return bool
   *   TRUE if stored, FALSE otherwise.
   */
  public function persistCodes(): bool;

  /**
   * Provides total code count.
   *
   * @return int
   *   Number of codes.
   */
  public function getCount(): int;

  /**
   * Provides total code count to dispense.
   *
   * @return int
   *   Number of codes.
   */
  public function getCountCodeAvailable(): int;

  /**
   * Checks if there any code available to dispense.
   *
   * @return bool
   *   TRUE if available. FALSE otherwise.
   */
  public function hasCodeAvailable(): bool;

  /**
   * Dispense a code.
   *
   * @param array $params
   *   Optional information for the dispenseCodes implementation.
   *
   * @return string
   *   The code.
   */
  public function dispenseCode(array $params = []): string;

  /**
   * Dispense codes.
   *
   * @param array $params
   *   Optional information for the dispenseCodes implementation.
   *
   * @return array
   *   The array of codes.
   */
  public function dispenseCodes(array $params = []): array;

}
