<?php

namespace Drupal\codes_pool_test\Plugin\codes_pool\CollectionSource;

use Drupal\codes_pool\Plugin\codes_pool\CodesStorage\CodesStorageInterface;
use Drupal\codes_pool\Plugin\codes_pool\CollectionSource\CollectionSourceBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the Local source for collection.
 *
 * @CodeCollectionSource(
 *   id = "codes_pool_testing_local_source",
 *   label = @Translation("Testing Codes Pool Local Source"),
 *   entity_type = "codes_pool_collection",
 *   storage = "codes_pool_testing_local_storage"
 * )
 */
class LocalSource extends CollectionSourceBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form += parent::buildConfigurationForm($form, $form_state);

    // Clear config form.
    $form['#type'] = 'container';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function postSave() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function getCount(): int {
    return CodesStorageInterface::CODE_COUNT_UNLIMITED;
  }

  /**
   * {@inheritdoc}
   */
  public function getCountCodeAvailable(): int {
    return CodesStorageInterface::CODE_COUNT_UNLIMITED;
  }

  /**
   * {@inheritdoc}
   */
  public function hasCodeAvailable(): bool {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function dispenseCode(array $params = []): string {
    // Set quantity to 1.
    $params['quantity'] = 1;

    return $this->getCodesStorage()->dispenseCode($params);
  }

  /**
   * {@inheritdoc}
   */
  public function dispenseCodes(array $params = []): array {
    return $this->getCodesStorage()->dispenseCodes($params);
  }

}
